<?php
/**
 * @file
 * Calls results to administration's pages for the Only One module.
 */

/**
 * Form constructor for module configuration.
 *
 */
function onlyone_admin_settings($form_state) {
  //getting all the content types
  $content_types_list = node_type_get_types();
  $available_content_type = array();
  $not_available_content_type = array();
  $form = array();

  foreach ($content_types_list as $key => $type) {
    if (drupal_multilingual()) {
      $result = db_query("SELECT language, COUNT(nid) AS total FROM {node} WHERE type = :key GROUP BY language ORDER BY language ASC", array(':key' => $key));

      if ($result->rowCount() > 0) {
        //Total of nodes by language
        $total = '';
        //Is the content type available for Only One?
        $available = TRUE;
        foreach ($result as $content_type) {
          //If the language is empty then it this Undetermined
          if ($content_type->language == 'und' || empty($content_type->language)) {
            $content_type->language = t('Undetermined');
          }
          else {
            $content_type->language = ucfirst($content_type->language);
          }

          $total .= $content_type->language . ': ' . $content_type->total . ' ' . format_plural($content_type->total, 'Node', 'Nodes') . ', ';
          //If one of the node total by language is greater than 1, then the content type is not available
          if ($content_type->total > 1) {
            $available = FALSE;
          }
        }
      }
      else {
        $total = 0 . ' ' . t('Node');
        $available = TRUE;
      }

      //Eliminating the last ', '
      $value = $type->name . ' <b>(' . rtrim($total, ', ') . ')</b>';

      if ($available) {
        $available_content_type[$key] = $value;
      }
      else {
        $not_available_content_type[$key] = $value;
      }
    }
    else {
      //If the site is not multilingual we have Only One language
      $result = db_query("SELECT COUNT(nid) as total FROM {node} WHERE type = :key", array(':key' => $key));
      $total = $result->fetchField();

      $value = $type->name . ' <b>(' . $total . ' ' . t('Nodes') . ')</b>';
      //If we have more than one node the content type is not available for Only One feature.
      if ($total > 1) {
        $not_available_content_type[$key] = $value;
      }
      else {
        $available_content_type[$key] = $value;
      }
    }
  }

  if (count($available_content_type) > 0) {
    //The fieldset of availables content types
    $form['available_content_type'] = array(
      '#type' => 'fieldset',
      '#title' => t('Available content types for Only One'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    //All the availables content types
    $form['available_content_type']['onlyone_node_types'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Configurate these content types to allow the creation of Only One node per language'),
      '#options' => $available_content_type,
      '#default_value' => variable_get('onlyone_node_types', array()),
      '#description' => t('The selected content types will allow Only One node per language.'),
    );
  }
  //If all the content types are availables we don't need to show the following fieldset
  if (count($not_available_content_type) > 0) {
    $collapsed = count($available_content_type) > 0 ? TRUE : FALSE;

    $form['not_available_content_type'] = array(
      '#type' => 'fieldset',
      '#title' => t('Not available content types for Only One'),
      '#description' => t('The following content types have more than one node in at least one language:'),
      '#collapsible' => $collapsed,
      '#collapsed' => $collapsed,
    );
    //showing all the not availables content types
    foreach ($not_available_content_type as $key => $value) {
      $form['not_available_content_type'][$key] = array(
        '#type' => 'item',
        '#markup' => $value,
      );
    }
  }
  //show the submit button if there is availables content types
  if (count($available_content_type) > 0) {
    return system_settings_form($form);
  }
  else {
    $form = system_settings_form($form);
    unset($form['actions']);
    return $form;
  }
}